==> gitlab-foss-v18.4.3.tar.bz2: gitlab-foss-v18.4.3/rubocop/cop/rspec/be_success_matcher.rb <==
# frozen_string_literal: true

require 'rubocop-rspec'

module RuboCop
  module Cop
    module RSpec
      # Checks for `be_success` usage in controller specs
      #
      # @example
      #
      #   # bad
      #   it "responds with success" do
      #     expect(response).to be_success
      #   end
      #
      #   it { is_expected.to be_success }
      #
      #   # good
      #   it "responds with success" do
      #     expect(response).to be_successful
      #   end
      #
      #   it { is_expected.to be_successful }
      #
      class BeSuccessMatcher < RuboCop::Cop::Base
        extend RuboCop::Cop::AutoCorrector

        MESSAGE = 'Do not use `be_success` (wraps deprecated `success?`); use `be_successful` instead.'

        # @!method expect_to_be_success?(node)
        def_node_search :expect_to_be_success?, <<~PATTERN
          (send (send nil? :expect (send nil? ...)) {:to :not_to :to_not} (send nil? :be_success))
        PATTERN

        # @!method is_expected_to_be_success?(node)
        def_node_search :is_expected_to_be_success?, <<~PATTERN
          (send (send nil? :is_expected) {:to :not_to :to_not} (send nil? :be_success))
        PATTERN

        def be_success_usage?(node)
          expect_to_be_success?(node) || is_expected_to_be_success?(node)
        end

        def on_send(node)
          return unless be_success_usage?(node)

          add_offense(node, message: MESSAGE) do |corrector|
            corrector.insert_after(node.loc.expression, 'ful')
          end
        end
      end
    end
  end
end

==> gitlab-foss-v18.7.1.tar.bz2: gitlab-foss-v18.7.1/rubocop/cop/rspec/be_success_matcher.rb <==
# frozen_string_literal: true

require 'rubocop-rspec'

module RuboCop
  module Cop
    module RSpec
      # Checks for `be_success` usage in controller specs
      #
      # @example
      #
      #   # bad
      #   it "responds with success" do
      #     expect(response).to be_success
      #   end
      #
      #   it { is_expected.to be_success }
      #
      #   # good
      #   it "responds with success" do
      #     expect(response).to be_successful
      #   end
      #
      #   it { is_expected.to be_successful }
      #
      class BeSuccessMatcher < RuboCop::Cop::Base
        extend RuboCop::Cop::AutoCorrector

        MESSAGE = 'Do not use `be_success` (wraps deprecated `success?`); use `be_successful` instead.'

        # @!method expect_to_be_success?(node)
        def_node_search :expect_to_be_success?, <<~PATTERN
          (send (send nil? :expect (send nil? ...)) {:to :not_to :to_not} (send nil? :be_success))
        PATTERN

        # @!method is_expected_to_be_success?(node)
        def_node_search :is_expected_to_be_success?, <<~PATTERN
          (send (send nil? :is_expected) {:to :not_to :to_not} (send nil? :be_success))
        PATTERN

        def be_success_usage?(node)
          expect_to_be_success?(node) || is_expected_to_be_success?(node)
        end

        def on_send(node)
          return unless be_success_usage?(node)

          add_offense(node, message: MESSAGE) do |corrector|
            corrector.insert_after(node, 'ful')
          end
        end
      end
    end
  end
end
